@@ -73,6 +73,7 @@ typedef enum {
 struct _SearchStruct {
 	gint			pid;
 	gint 	        	timeout;
+	gchar			*look_in_folder;
 	gchar           	*file_is_named_pattern;
 	gchar 	  		*regex_string;
 	gboolean		lock;	
@@ -92,6 +93,7 @@ struct _InterfaceStruct {
 	GtkWidget 		*status_bar;
 	GtkWidget   		*progress_bar;
 	GtkWidget	 	*disclosure;
+	GtkWidget		*add_button;
 	GtkWidget 		*additional_constraints;
 	GtkWidget		*constraint_menu;
 	GtkWidget 		*constraint;
